searchData={"items":[{"type":"module","title":"EDTF","doc":"Parse, validate, and humanize EDTF date strings","ref":"EDTF.html"},{"type":"function","title":"EDTF.error/1","doc":"Generate an error response","ref":"EDTF.html#error/1"},{"type":"function","title":"EDTF.humanize/1","doc":"Humanize an EDTF date string\n\nExample:\n  ```elixir\n  iex> humanize(\"1999-06-10\")\n  \"June 10, 1999\"\n\n  iex> humanize(\"bad date!\")\n  {:error, :invalid_format}\n  ```","ref":"EDTF.html#humanize/1"},{"type":"function","title":"EDTF.open_ended/1","doc":"Identify the open-ended continuation markers on an EDTF date string","ref":"EDTF.html#open_ended/1"},{"type":"function","title":"EDTF.parse/2","doc":"Parse an EDTF date string\n\nExample:\n  ```elixir\n  iex> parse(\"1999-06-10\")\n  {:ok, %EDTF.Date{level: 0, type: :date, values: [1999, 5, 10]}}\n\n  iex> parse(\"bad date!\")\n  {:error, :invalid_format}\n  ```","ref":"EDTF.html#parse/2"},{"type":"function","title":"EDTF.validate/1","doc":"Validate an EDTF date string\n\nExample:\n  ```elixir\n  iex> validate(\"1999-06-10\")\n  {:ok, \"1999-06-10\"}\n\n  iex> validate(\"bad date!\")\n  {:error, :invalid_format}\n  ```","ref":"EDTF.html#validate/1"},{"type":"module","title":"EDTF.Aggregate","doc":"Parser for EDTF Lists and Sets","ref":"EDTF.Aggregate.html"},{"type":"function","title":"EDTF.Aggregate.match?/1","doc":"","ref":"EDTF.Aggregate.html#match?/1"},{"type":"function","title":"EDTF.Aggregate.parse/1","doc":"","ref":"EDTF.Aggregate.html#parse/1"},{"type":"type","title":"EDTF.Aggregate.t/0","doc":"","ref":"EDTF.Aggregate.html#t:t/0"},{"type":"module","title":"EDTF.Continuation","doc":"EDTF Continuation Struct","ref":"EDTF.Continuation.html"},{"type":"type","title":"EDTF.Continuation.t/0","doc":"","ref":"EDTF.Continuation.html#t:t/0"},{"type":"module","title":"EDTF.Date","doc":"Parser for basic EDTF dates, including year, and decade","ref":"EDTF.Date.html"},{"type":"function","title":"EDTF.Date.match?/1","doc":"","ref":"EDTF.Date.html#match?/1"},{"type":"function","title":"EDTF.Date.parse/1","doc":"","ref":"EDTF.Date.html#parse/1"},{"type":"type","title":"EDTF.Date.edtf_attribute/0","doc":"","ref":"EDTF.Date.html#t:edtf_attribute/0"},{"type":"type","title":"EDTF.Date.edtf_type/0","doc":"","ref":"EDTF.Date.html#t:edtf_type/0"},{"type":"type","title":"EDTF.Date.t/0","doc":"","ref":"EDTF.Date.html#t:t/0"},{"type":"module","title":"EDTF.Humanize","doc":"Convert EDTF dates to human readable form","ref":"EDTF.Humanize.html"},{"type":"function","title":"EDTF.Humanize.humanize/1","doc":"","ref":"EDTF.Humanize.html#humanize/1"},{"type":"module","title":"EDTF.Humanize.Aggregate","doc":"Humanize EDTF Set and List types","ref":"EDTF.Humanize.Aggregate.html"},{"type":"function","title":"EDTF.Humanize.Aggregate.humanize/1","doc":"","ref":"EDTF.Humanize.Aggregate.html#humanize/1"},{"type":"module","title":"EDTF.Humanize.Date","doc":"Humanize EDTF Date, Year, Decade, Century, and Season types","ref":"EDTF.Humanize.Date.html"},{"type":"function","title":"EDTF.Humanize.Date.humanize/1","doc":"","ref":"EDTF.Humanize.Date.html#humanize/1"},{"type":"module","title":"EDTF.Infinity","doc":"EDTF Infinity struct","ref":"EDTF.Infinity.html"},{"type":"function","title":"EDTF.Infinity.match?/1","doc":"","ref":"EDTF.Infinity.html#match?/1"},{"type":"function","title":"EDTF.Infinity.parse/1","doc":"","ref":"EDTF.Infinity.html#parse/1"},{"type":"type","title":"EDTF.Infinity.t/0","doc":"","ref":"EDTF.Infinity.html#t:t/0"},{"type":"module","title":"EDTF.Interval","doc":"Parser for EDTF Intervals","ref":"EDTF.Interval.html"},{"type":"function","title":"EDTF.Interval.match?/1","doc":"","ref":"EDTF.Interval.html#match?/1"},{"type":"function","title":"EDTF.Interval.parse/1","doc":"","ref":"EDTF.Interval.html#parse/1"},{"type":"type","title":"EDTF.Interval.t/0","doc":"","ref":"EDTF.Interval.html#t:t/0"},{"type":"module","title":"EDTF.Range","doc":"Parser for EDTF Ranges","ref":"EDTF.Range.html"},{"type":"function","title":"EDTF.Range.match?/1","doc":"","ref":"EDTF.Range.html#match?/1"},{"type":"function","title":"EDTF.Range.parse/1","doc":"","ref":"EDTF.Range.html#parse/1"},{"type":"module","title":"EDTF.Season","doc":"Parser for EDTF Seasons","ref":"EDTF.Season.html"},{"type":"function","title":"EDTF.Season.match?/1","doc":"","ref":"EDTF.Season.html#match?/1"},{"type":"function","title":"EDTF.Season.parse/1","doc":"","ref":"EDTF.Season.html#parse/1"},{"type":"module","title":"EDTF.Year","doc":"Parser for EDTF Level 1 Years","ref":"EDTF.Year.html"},{"type":"function","title":"EDTF.Year.match?/1","doc":"","ref":"EDTF.Year.html#match?/1"},{"type":"function","title":"EDTF.Year.parse/1","doc":"","ref":"EDTF.Year.html#parse/1"},{"type":"extras","title":"EDTF","doc":"# EDTF\n\n[![Build](https://github.com/nulib/edtf_ex/actions/workflows/build.yml/badge.svg)](https://github.com/nulib/edtf_ex/actions/workflows/build.yml)\n[![Coverage](https://coveralls.io/repos/github/nulib/edtf_ex/badge.svg?branch=main)](https://coveralls.io/github/nulib/edtf_ex?branch=main)\n[![Hex.pm](https://img.shields.io/hexpm/v/edtf.svg)](https://hex.pm/packages/edtf)\n\nAn Extended Date Time Format (EDTF) / ISO 8601-2 parser and English language rendering\ntoolkit for Elixir.","ref":"readme.html"},{"type":"extras","title":"Compatibility - EDTF","doc":"","ref":"readme.html#compatibility"},{"type":"extras","title":"EDTF / ISO 8601-2 - EDTF","doc":"EDTF fully implements [EDTF](http://www.loc.gov/standards/datetime)\nlevels 0, 1, and 2 as specified by ISO 8601-2","ref":"readme.html#edtf-iso-8601-2"},{"type":"extras","title":"Installation - EDTF","doc":"Add `edtf` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:edtf, \"~> 1.0.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - EDTF","doc":"See `EDTF.parse/1`, `EDTF.validate/1`, and `EDTF.humanize/1`.","ref":"readme.html#usage"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}